@@ -19,6 +19,9 @@ mod error;
 pub use error::Error;
 mod torrent;
 pub use torrent::Torrent;
+#[cfg(any(feature = "parse-names", feature = "require-parse-names"))]
+/// Re-exported from [`torrent-name-parser`](torrent_name_parser::Metadata)
+pub use torrent_name_parser::Metadata;
 
 #[derive(Clone)]
 pub struct Client {
